@@ -3,7 +3,7 @@ package Specio::Library::Structured::Map;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.37';
 
 use Carp qw( confess );
 use List::Util ();
@@ -16,7 +16,7 @@ sub parent {$hashref}
 
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _inline {
-    $hashref->_inline_check( $_[1] );
+    $hashref->inline_check( $_[1] );
 }
 
 sub _parameterization_args_builder {
@@ -88,7 +88,7 @@ Specio::Library::Structured::Map - Guts of Map structured type
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 DESCRIPTION
 
